condition_codes = [
 {
   "code": 200,
   "condition": "Thunderstorm",
   "description": "thunderstorm with light rain",
   "icon": "11d"
 },
 {
   "code": 201,
   "condition": "Thunderstorm",
   "description": "thunderstorm with rain",
   "icon": "11d"
 },
 {
   "code": 202,
   "condition": "Thunderstorm",
   "description": "thunderstorm with heavy rain",
   "icon": "11d"
 },
 {
   "code": 210,
   "condition": "Thunderstorm",
   "description": "light thunderstorm",
   "icon": "11d"
 },
 {
   "code": 211,
   "condition": "Thunderstorm",
   "description": "thunderstorm",
   "icon": "11d"
 },
 {
   "code": 212,
   "condition": "Thunderstorm",
   "description": "heavy thunderstorm",
   "icon": "11d"
 },
 {
   "code": 221,
   "condition": "Thunderstorm",
   "description": "ragged thunderstorm",
   "icon": "11d"
 },
 {
   "code": 230,
   "condition": "Thunderstorm",
   "description": "thunderstorm with light drizzle",
   "icon": "11d"
 },
 {
   "code": 231,
   "condition": "Thunderstorm",
   "description": "thunderstorm with drizzle",
   "icon": "11d"
 },
 {
   "code": 232,
   "condition": "Thunderstorm",
   "description": "thunderstorm with heavy drizzle",
   "icon": "11d"
 },
 {
   "code": 300,
   "condition": "Drizzle",
   "description": "light intensity drizzle",
   "icon": "09d"
 },
 {
   "code": 301,
   "condition": "Drizzle",
   "description": "drizzle",
   "icon": "09d"
 },
 {
   "code": 302,
   "condition": "Drizzle",
   "description": "heavy intensity drizzle",
   "icon": "09d"
 },
 {
   "code": 310,
   "condition": "Drizzle",
   "description": "light intensity drizzle rain",
   "icon": "09d"
 },
 {
   "code": 311,
   "condition": "Drizzle",
   "description": "drizzle rain",
   "icon": "09d"
 },
 {
   "code": 312,
   "condition": "Drizzle",
   "description": "heavy intensity drizzle rain",
   "icon": "09d"
 },
 {
   "code": 313,
   "condition": "Drizzle",
   "description": "shower rain and drizzle",
   "icon": "09d"
 },
 {
   "code": 314,
   "condition": "Drizzle",
   "description": "heavy shower rain and drizzle",
   "icon": "09d"
 },
 {
   "code": 321,
   "condition": "Drizzle",
   "description": "shower drizzle",
   "icon": "09d"
 },
 {
   "code": 500,
   "condition": "Rain",
   "description": "light rain",
   "icon": "10d"
 },
 {
   "code": 501,
   "condition": "Rain",
   "description": "moderate rain",
   "icon": "10d"
 },
 {
   "code": 502,
   "condition": "Rain",
   "description": "heavy intensity rain",
   "icon": "10d"
 },
 {
   "code": 503,
   "condition": "Rain",
   "description": "very heavy rain",
   "icon": "10d"
 },
 {
   "code": 504,
   "condition": "Rain",
   "description": "extreme rain",
   "icon": "10d"
 },
 {
   "code": 511,
   "condition": "Rain",
   "description": "freezing rain",
   "icon": "13d"
 },
 {
   "code": 520,
   "condition": "Rain",
   "description": "light intensity shower rain",
   "icon": "09d"
 },
 {
   "code": 521,
   "condition": "Rain",
   "description": "shower rain",
   "icon": "09d"
 },
 {
   "code": 522,
   "condition": "Rain",
   "description": "heavy intensity shower rain",
   "icon": "09d"
 },
 {
   "code": 531,
   "condition": "Rain",
   "description": "ragged shower rain",
   "icon": "09d"
 },
 {
   "code": 600,
   "condition": "Snow",
   "description": "light snow",
   "icon": "13d"
 },
 {
   "code": 601,
   "condition": "Snow",
   "description": "Snow",
   "icon": "13d"
 },
 {
   "code": 602,
   "condition": "Snow",
   "description": "Heavy snow",
   "icon": "13d"
 },
 {
   "code": 611,
   "condition": "Snow",
   "description": "Sleet",
   "icon": "13d"
 },
 {
   "code": 612,
   "condition": "Snow",
   "description": "Light shower sleet",
   "icon": "13d"
 },
 {
   "code": 613,
   "condition": "Snow",
   "description": "Shower sleet",
   "icon": "13d"
 },
 {
   "code": 615,
   "condition": "Snow",
   "description": "Light rain and snow",
   "icon": "13d"
 },
 {
   "code": 616,
   "condition": "Snow",
   "description": "Rain and snow",
   "icon": "13d"
 },
 {
   "code": 620,
   "condition": "Snow",
   "description": "Light shower snow",
   "icon": "13d"
 },
 {
   "code": 621,
   "condition": "Snow",
   "description": "Shower snow",
   "icon": "13d"
 },
 {
   "code": 622,
   "condition": "Snow",
   "description": "Heavy shower snow",
   "icon": "13d"
 },
 {
   "code": 701,
   "condition": "Mist",
   "description": "mist",
   "icon": "50d"
 },
 {
   "code": 711,
   "condition": "Smoke",
   "description": "Smoke",
   "icon": "50d"
 },
 {
   "code": 721,
   "condition": "Haze",
   "description": "Haze",
   "icon": "50d"
 },
 {
   "code": 731,
   "condition": "Dust",
   "description": "sand/ dust whirls",
   "icon": "50d"
 },
 {
   "code": 741,
   "condition": "Fog",
   "description": "fog",
   "icon": "50d"
 },
 {
   "code": 751,
   "condition": "Sand",
   "description": "sand",
   "icon": "50d"
 },
 {
   "code": 761,
   "condition": "Dust",
   "description": "dust",
   "icon": "50d"
 },
 {
   "code": 762,
   "condition": "Ash",
   "description": "volcanic ash",
   "icon": "50d"
 },
 {
   "code": 771,
   "condition": "Squall",
   "description": "squalls",
   "icon": "50d"
 },
 {
   "code": 781,
   "condition": "Tornado",
   "description": "tornado",
   "icon": "50d"
 },
 {
   "code": 800,
   "condition": "Clear",
   "description": "clear sky",
   "icon": "01d"
 },
 {
   "code": 801,
   "condition": "Clouds",
   "description": "few clouds: 11-25%",
   "icon": "02d"
 },
 {
   "code": 802,
   "condition": "Clouds",
   "description": "scattered clouds: 25-50%",
   "icon": "03d"
 },
 {
   "code": 803,
   "condition": "Clouds",
   "description": "broken clouds: 51-84%",
   "icon": "04d"
 },
 {
   "code": 804,
   "condition": "Clouds",
   "description": "overcast clouds: 85-100%",
   "icon": "04d"
 }
]
